ClassInfo class

Information about a class

Constructors

ClassInfo({required String name, String? extendsClass, required List<String> implements, required List<String> annotations, required List<MethodInfo> methods})

Properties

annotations List<String>
final
extendsClass String?
final
hashCode int
The hash code for this object.
no setterinherited
implements List<String>
final
methods List<MethodInfo>
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited