CodeParser class

Parser for extracting information from Vaden Dart code

Constructors

CodeParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

extractClassInfo(String filePath) Future<ClassInfo?>
Extract class information from a Dart file
extractImports(String filePath) Future<List<String>>
Extract imports from a file
extractRoutes(String filePath) Future<List<RouteInfo>>
Extract route information from a controller