MCPRequest class

Constructors

MCPRequest({String jsonrpc = '2.0', required dynamic id, required String method, Map<String, dynamic>? params})
MCPRequest.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id → dynamic
final
jsonrpc String
final
method String
final
params Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited