ConfigurationTemplate class

Templates for generating Vaden configurations

Constructors

ConfigurationTemplate()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateBeanMethod({required String methodName, required String returnType}) String
Generate a bean method
generateConfiguration({required String className, String? description}) String
Generate a basic configuration class
generateDatabaseConfiguration() String
Generate database configuration template
generateOpenApiConfiguration() String
Generate OpenAPI configuration
generateSecurityConfiguration() String
Generate security configuration template