ControllerTemplate class

Templates for generating Vaden controllers

Constructors

ControllerTemplate()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateController({required String className, required String route, String? description, bool includeRudMethods = false}) String
Generate a basic REST controller
generateRouteMethod({required String httpMethod, required String path, required String methodName, required String returnType, List<Map<String, String>>? parameters}) String
Generate a route method