ServiceTemplate class

Templates for generating Vaden services

Constructors

ServiceTemplate()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateService({required String className, String? description}) String
Generate a basic service
generateServiceMethod({required String methodName, required String returnType, List<Map<String, String>>? parameters}) String
Generate a service method