ProjectTools class

MCP tools for project introspection

Constructors

ProjectTools(String projectRoot)

Properties

hashCode int
The hash code for this object.
no setterinherited
projectRoot String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConfiguration(Map<String, dynamic> params) Future<Map<String, dynamic>>
Get configuration
listControllers(Map<String, dynamic> params) Future<Map<String, dynamic>>
List all controllers
listModules(Map<String, dynamic> params) Future<Map<String, dynamic>>
List all modules
listRepositories(Map<String, dynamic> params) Future<Map<String, dynamic>>
List all repositories
listServices(Map<String, dynamic> params) Future<Map<String, dynamic>>
List all services
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scanProject(Map<String, dynamic> params) Future<Map<String, dynamic>>
Scan project structure
toString() String
A string representation of this object.
inherited
validateProject(Map<String, dynamic> params) Future<Map<String, dynamic>>
Validate Vaden project

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

getConfigurationInfo MCPToolInfo
Get tool info for get_configuration
no setter
listControllersInfo MCPToolInfo
Get tool info for list_controllers
no setter
listModulesInfo MCPToolInfo
Get tool info for list_modules
no setter
listRepositoriesInfo MCPToolInfo
Get tool info for list_repositories
no setter
listServicesInfo MCPToolInfo
Get tool info for list_services
no setter
scanProjectInfo MCPToolInfo
Get tool info for scan_project
no setter
validateProjectInfo MCPToolInfo
Get tool info for validate_vaden_project
no setter