ProjectScanner class
Scanner for analyzing Vaden project structure
Constructors
- ProjectScanner(String projectRoot)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectRoot → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
findConfigurations(
) → Future< List< String> > - Find all configurations in the project
-
findControllers(
) → Future< List< String> > - Find all controllers in the project
-
findDTOs(
) → Future< List< String> > - Find all DTOs in the project
-
findMainApplicationFile(
) → Future< String?> - Find main application file
-
findModules(
) → Future< List< String> > - Find all modules in the project
-
findRepositories(
) → Future< List< String> > - Find all repositories in the project
-
findServices(
) → Future< List< String> > - Find all services in the project
-
getApplicationConfig(
) → Future< Map< String, dynamic> ?> - Get application.yaml configuration
-
getProjectName(
) → Future< String?> - Get project name from pubspec.yaml
-
getProjectSummary(
) → Future< Map< String, dynamic> > - Get project structure summary
-
isVadenProject(
) → Future< bool> - Check if the current directory is a valid Vaden project
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited