CodegenTools class
MCP tools for code generation and mutation
Constructors
- CodegenTools(String projectRoot)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectRoot → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addRouteToController(
Map< String, dynamic> params) → Future<Map< String, dynamic> > - Add route to existing controller
-
createConfiguration(
Map< String, dynamic> params) → Future<Map< String, dynamic> > - Create configuration
-
createController(
Map< String, dynamic> params) → Future<Map< String, dynamic> > - Create a new controller
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- addRouteInfo → MCPToolInfo
-
Get tool info for add_route_to_controller
no setter
- createConfigurationInfo → MCPToolInfo
-
Get tool info for create_configuration
no setter
- createControllerInfo → MCPToolInfo
-
Get tool info for create_controller
no setter